LibCallResolver

Enum LibCallResolver 

pub enum LibCallResolver {
Show 87 variants CeilF32, CeilF64, FloorF32, FloorF64, NearestF32, NearestF64, TruncF32, TruncF64, Memory32Size, ImportedMemory32Size, TableCopy, TableInit, TableFill, TableSize, ImportedTableSize, TableGet, ImportedTableGet, TableSet, ImportedTableSet, TableGrow, ImportedTableGrow, FuncRef, ElemDrop, Memory32Copy, ImportedMemory32Copy, Memory32Fill, ImportedMemory32Fill, Memory32Init, DataDrop, RaiseTrap, Probestack, Memory32AtomicWait32, ImportedMemory32AtomicWait32, Memory32AtomicWait64, ImportedMemory32AtomicWait64, Memory32AtomicNotify, ImportedMemory32AtomicNotify, Throw, AllocException, ReadExnRef, LibunwindExceptionIntoExnRef, EHPersonality, EHPersonality2, DebugUsize, DebugStr, Addsf3, Adddf3, Subsf3, Subdf3, Mulsf3, Muldf3, Divsf3, Divdf3, Negsf2, Negdf2, Extendsfdf2, Truncdfsf2, Fixsfsi, Fixdfsi, Fixsfdi, Fixdfdi, Fixunssfsi, Fixunsdfsi, Fixunssfdi, Fixunsdfdi, Floatsisf, Floatsidf, Floatdisf, Floatdidf, Floatunsisf, Floatunsidf, Floatundisf, Floatundidf, Unordsf2, Unorddf2, Eqsf2, Eqdf2, Nesf2, Nedf2, Gesf2, Gedf2, Ltsf2, Ltdf2, Lesf2, Ledf2, Gtsf2, Gtdf2,
}
The resolver for an archived LibCall

Variants



CeilF32

The resolver for LibCall::CeilF32



CeilF64

The resolver for LibCall::CeilF64



FloorF32

The resolver for LibCall::FloorF32



FloorF64

The resolver for LibCall::FloorF64



NearestF32

The resolver for LibCall::NearestF32



NearestF64

The resolver for LibCall::NearestF64



TruncF32

The resolver for LibCall::TruncF32



TruncF64

The resolver for LibCall::TruncF64



Memory32Size

The resolver for LibCall::Memory32Size



ImportedMemory32Size



TableCopy

The resolver for LibCall::TableCopy



TableInit

The resolver for LibCall::TableInit



TableFill

The resolver for LibCall::TableFill



TableSize

The resolver for LibCall::TableSize



ImportedTableSize

The resolver for LibCall::ImportedTableSize



TableGet

The resolver for LibCall::TableGet



ImportedTableGet

The resolver for LibCall::ImportedTableGet



TableSet

The resolver for LibCall::TableSet



ImportedTableSet

The resolver for LibCall::ImportedTableSet



TableGrow

The resolver for LibCall::TableGrow



ImportedTableGrow

The resolver for LibCall::ImportedTableGrow



FuncRef

The resolver for LibCall::FuncRef



ElemDrop

The resolver for LibCall::ElemDrop



Memory32Copy

The resolver for LibCall::Memory32Copy



ImportedMemory32Copy



Memory32Fill

The resolver for LibCall::Memory32Fill



ImportedMemory32Fill



Memory32Init

The resolver for LibCall::Memory32Init



DataDrop

The resolver for LibCall::DataDrop



RaiseTrap

The resolver for LibCall::RaiseTrap



Probestack

The resolver for LibCall::Probestack



Memory32AtomicWait32



ImportedMemory32AtomicWait32



Memory32AtomicWait64



ImportedMemory32AtomicWait64



Memory32AtomicNotify



ImportedMemory32AtomicNotify



Throw

The resolver for LibCall::Throw



AllocException

The resolver for LibCall::AllocException



ReadExnRef

The resolver for LibCall::ReadExnRef



LibunwindExceptionIntoExnRef



EHPersonality

The resolver for LibCall::EHPersonality



EHPersonality2

The resolver for LibCall::EHPersonality2



DebugUsize

The resolver for LibCall::DebugUsize



DebugStr

The resolver for LibCall::DebugStr



Addsf3

The resolver for LibCall::Addsf3



Adddf3

The resolver for LibCall::Adddf3



Subsf3

The resolver for LibCall::Subsf3



Subdf3

The resolver for LibCall::Subdf3



Mulsf3

The resolver for LibCall::Mulsf3



Muldf3

The resolver for LibCall::Muldf3



Divsf3

The resolver for LibCall::Divsf3



Divdf3

The resolver for LibCall::Divdf3



Negsf2

The resolver for LibCall::Negsf2



Negdf2

The resolver for LibCall::Negdf2



Extendsfdf2

The resolver for LibCall::Extendsfdf2



Truncdfsf2

The resolver for LibCall::Truncdfsf2



Fixsfsi

The resolver for LibCall::Fixsfsi



Fixdfsi

The resolver for LibCall::Fixdfsi



Fixsfdi

The resolver for LibCall::Fixsfdi



Fixdfdi

The resolver for LibCall::Fixdfdi



Fixunssfsi

The resolver for LibCall::Fixunssfsi



Fixunsdfsi

The resolver for LibCall::Fixunsdfsi



Fixunssfdi

The resolver for LibCall::Fixunssfdi



Fixunsdfdi

The resolver for LibCall::Fixunsdfdi



Floatsisf

The resolver for LibCall::Floatsisf



Floatsidf

The resolver for LibCall::Floatsidf



Floatdisf

The resolver for LibCall::Floatdisf



Floatdidf

The resolver for LibCall::Floatdidf



Floatunsisf

The resolver for LibCall::Floatunsisf



Floatunsidf

The resolver for LibCall::Floatunsidf



Floatundisf

The resolver for LibCall::Floatundisf



Floatundidf

The resolver for LibCall::Floatundidf



Unordsf2

The resolver for LibCall::Unordsf2



Unorddf2

The resolver for LibCall::Unorddf2



Eqsf2

The resolver for LibCall::Eqsf2



Eqdf2

The resolver for LibCall::Eqdf2



Nesf2

The resolver for LibCall::Nesf2



Nedf2

The resolver for LibCall::Nedf2



Gesf2

The resolver for LibCall::Gesf2



Gedf2

The resolver for LibCall::Gedf2



Ltsf2

The resolver for LibCall::Ltsf2



Ltdf2

The resolver for LibCall::Ltdf2



Lesf2

The resolver for LibCall::Lesf2



Ledf2

The resolver for LibCall::Ledf2



Gtsf2

The resolver for LibCall::Gtsf2



Gtdf2

The resolver for LibCall::Gtdf2