Struct wasmer_types::HostRef [−][src]
Represents a piece of data located in the host environment.
Implementations
impl<T: 'static> HostRef<T>[src]
pub fn new(item: T) -> Self[src]
Creates a new HostRef<T> from T.
pub fn borrow(&self) -> Ref<'_, T>[src]
pub fn borrow_mut(&self) -> RefMut<'_, T>[src]
pub fn ptr_eq(&self, other: &Self) -> bool[src]
Returns true if the two HostRef<T>'s point to the same value (not just
values that compare as equal).
pub fn externref(&self) -> ExternRef[src]
Returns an opaque reference to the wrapped data in the form of
an ExternRef.
Panics
Panics if HostRef<T> is already mutably borrowed.