pub struct ImportType<T = ExternType> {
module: String,
name: String,
ty: T,
}Expand description
A descriptor for an imported value into a wasm module.
This type is primarily accessed from the Module::imports
API. Each ImportType describes an import into the wasm module
with the module/name that it’s imported from as well as the type
of item that’s being imported.
Fields
module: Stringname: Stringty: TImplementations
Sourceimpl<T> ImportType<T>
impl<T> ImportType<T>
Sourcepub fn new(module: &str, name: &str, ty: T) -> Self
pub fn new(module: &str, name: &str, ty: T) -> Self
Creates a new import descriptor which comes from module and name and
is of type ty.
Sourcepub fn module(&self) -> &str
pub fn module(&self) -> &str
Returns the module name that this import is expected to come from.