pub struct Pages(pub u32);Expand description
Units of WebAssembly pages (as specified to be 65,536 bytes).
Tuple Fields
0: u32Implementations
Sourceimpl Pages
impl Pages
Sourcepub const fn max_value() -> Self
pub const fn max_value() -> Self
Returns the largest value that can be represented by the Pages type.
This is defined by the WebAssembly standard as 65,536 pages.
Sourcepub fn checked_add(self, rhs: Self) -> Option<Self>
pub fn checked_add(self, rhs: Self) -> Option<Self>
Checked addition. Computes self + rhs,
returning None if overflow occurred.
Sourcepub fn from_bytes_rounded_up(bytes: u64) -> Option<Self>
pub fn from_bytes_rounded_up(bytes: u64) -> Option<Self>
Calculate the number of pages needed to hold the given number of bytes,
rounding up to include any partial page,
returning None if overflow occurred.