pub struct TableType {
pub ty: Type,
pub minimum: u32,
pub maximum: Option<u32>,
}Expand description
A descriptor for a table in a WebAssembly module.
Tables are contiguous chunks of a specific element, typically a funcref or
an externref. The most common use for tables is a function table through
which call_indirect can invoke other functions.
Fields
ty: TypeThe type of data stored in elements of the table.
minimum: u32The minimum number of elements in the table.
maximum: Option<u32>The maximum number of elements in the table.
Implementations
Sourceimpl TableType
impl TableType
Sourcepub fn new(ty: Type, minimum: u32, maximum: Option<u32>) -> Self
pub fn new(ty: Type, minimum: u32, maximum: Option<u32>) -> Self
Creates a new table descriptor which will contain the specified
element and have the limits applied to its length.
Sourcepub fn is_fixed_funcref_table(&self) -> bool
pub fn is_fixed_funcref_table(&self) -> bool
Return true if it’s a function reference table with a fixed number of elements.