pub fn vmctx_offset(offset: u32) -> WasmResult<i32>Expand description
Convert a VMContext offset to the signed displacement used by compilers.
pub fn vmctx_offset(offset: u32) -> WasmResult<i32>Convert a VMContext offset to the signed displacement used by compilers.