Display

Trait Display 

1.0.0 · Source
pub trait Display {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Available on crate feature std only.
Format trait for an empty format, {}.

Implementing this trait for a type will automatically implement the ToString trait for the type, allowing the usage of the .to_string() method. Prefer implementing the Display trait for a type, rather than ToString.

Display is similar to Debug, but Display is for user-facing output, and so cannot be derived.

For more information on formatters, see the module-level documentation.

Completeness and parseability

Display for a type might not necessarily be a lossless or complete representation of the type. It may omit internal state, precision, or other information the type does not consider important for user-facing output, as determined by the type. As such, the output of Display might not be possible to parse, and even if it is, the result of parsing might not exactly match the original value.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Internationalization

Because a type can only have one Display implementation, it is often preferable to only implement Display when there is a single most “obvious” way that values can be formatted as text. This could mean formatting according to the “invariant” culture and “undefined” locale, or it could mean that the type display is designed for a specific culture/locale, such as developer logs.

If not all values have a justifiably canonical textual format or if you want to support alternative formats not covered by the standard set of possible formatting traits, the most flexible approach is display adapters: methods like str::escape_default or Path::display which create a wrapper implementing Display to output the specific display format.

Examples

Implementing Display on a type:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Display for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.x, self.y)
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Display for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.longitude, self.latitude)
    }
}

assert_eq!(
    "(1.987, 2.983)",
    format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Display for !

Source

impl Display for Aarch64Architecture

1.26.0 · Source

impl Display for AccessError

1.4.0 · Source

impl Display for AddrParseError

Source

impl Display for AllocError

Source

impl Display for Architecture

Source

impl Display for ArchivedString

1.0.0 · Source

impl Display for Arguments<'_>

Source

impl Display for ArmArchitecture

Source

impl Display for AsciiChar

Source

impl Display for AtomicsError

1.65.0 · Source

impl Display for Backtrace

Source

impl Display for BinaryFormat

1.13.0 · Source

impl Display for BorrowError

1.13.0 · Source

impl Display for BorrowMutError

Source

impl Display for BoxedError

Source

impl Display for ByteStr

Source

impl Display for ByteString

1.34.0 · Source

impl Display for CharTryFromError

Source

impl Display for CleverArchitecture

Source

impl Display for CompileError

Source

impl Display for CpuFeature

1.9.0 · Source

impl Display for DecodeUtf16Error

Source

impl Display for DeserializeError

Source

impl Display for DeserializeStateError

1.87.0 · Source

impl Display for std::ffi::os_str::Display<'_>

1.0.0 · Source

impl Display for std::path::Display<'_>

Source

impl Display for Environment

1.0.0 · Source

impl Display for core::io::error::Error

1.0.0 · Source

impl Display for wasmer_types::lib::std::fmt::Error

Source

impl Display for rancor::Error

Source

impl Display for block_buffer::Error

Source

impl Display for const_oid::error::Error

Source

impl Display for getrandom::error::Error

1.60.0 · Source

impl Display for ErrorKind

1.20.0 · Source

impl Display for core::char::EscapeDebug

1.39.0 · Source

impl Display for core::ascii::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeUnicode

1.0.0 · Source

impl Display for ExitStatus

Source

impl Display for ExitStatusError

Source

impl Display for Failure

1.69.0 · Source

impl Display for FromBytesUntilNulError

1.17.0 · Source

impl Display for FromBytesWithNulError

Source

impl Display for FromHexError

1.0.0 · Source

impl Display for FromUtf8Error

1.0.0 · Source

impl Display for FromUtf16Error

1.58.0 · Source

impl Display for FromVecWithNulError

Source

impl Display for FunctionType

1.86.0 · Source

impl Display for wasmer_types::lib::std::slice::GetDisjointMutError

Source

impl Display for indexmap::GetDisjointMutError

Source

impl Display for GlobalType

Source

impl Display for ImportError

1.34.0 · Source

impl Display for Infallible

1.7.0 · Source

impl Display for IntoStringError

Source

impl Display for InvalidBufferSize

Source

impl Display for InvalidKey

Source

impl Display for InvalidLength

Source

impl Display for InvalidOutputSize

1.7.0 · Source

impl Display for IpAddr

1.0.0 · Source

impl Display for Ipv4Addr

1.0.0 · Source

impl Display for Ipv6Addr

Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.

Source

impl Display for IteratorLengthMismatch

1.0.0 · Source

impl Display for JoinPathsError

1.28.0 · Source

impl Display for LayoutError

Source

impl Display for LibCall

1.26.0 · Source

impl Display for Location<'_>

Source

impl Display for MemoryError

Source

impl Display for MemoryType

Source

impl Display for MiddlewareError

Source

impl Display for Mips32Architecture

Source

impl Display for Mips64Architecture

Source

impl Display for ModuleHash

Source

impl Display for ModuleInfo

Source

impl Display for NamedEnumVariantCheckContext

Source

impl Display for NonZeroI16_be

Source

impl Display for NonZeroI16_le

Source

impl Display for NonZeroI16_ube

Source

impl Display for NonZeroI16_ule

Source

impl Display for NonZeroI32_be

Source

impl Display for NonZeroI32_le

Source

impl Display for NonZeroI32_ube

Source

impl Display for NonZeroI32_ule

Source

impl Display for NonZeroI64_be

Source

impl Display for NonZeroI64_le

Source

impl Display for NonZeroI64_ube

Source

impl Display for NonZeroI64_ule

Source

impl Display for NonZeroI128_be

Source

impl Display for NonZeroI128_le

Source

impl Display for NonZeroI128_ube

Source

impl Display for NonZeroI128_ule

Source

impl Display for NonZeroU16_be

Source

impl Display for NonZeroU16_le

Source

impl Display for NonZeroU16_ube

Source

impl Display for NonZeroU16_ule

Source

impl Display for NonZeroU32_be

Source

impl Display for NonZeroU32_le

Source

impl Display for NonZeroU32_ube

Source

impl Display for NonZeroU32_ule

Source

impl Display for NonZeroU64_be

Source

impl Display for NonZeroU64_le

Source

impl Display for NonZeroU64_ube

Source

impl Display for NonZeroU64_ule

Source

impl Display for NonZeroU128_be

Source

impl Display for NonZeroU128_le

Source

impl Display for NonZeroU128_ube

Source

impl Display for NonZeroU128_ule

Source

impl Display for NormalizeError

1.0.0 · Source

impl Display for NulError

Source

impl Display for ObjectIdentifierRef

Source

impl Display for OperatingSystem

Source

impl Display for PageCountOutOfRange

Source

impl Display for Panic

1.26.0 · Source

impl Display for PanicHookInfo<'_>

1.26.0 · Source

impl Display for PanicInfo<'_>

1.81.0 · Source

impl Display for PanicMessage<'_>

1.0.0 · Source

impl Display for ParseBoolError

1.20.0 · Source

impl Display for ParseCharError

Source

impl Display for ParseCpuFeatureError

Source

impl Display for ParseError

1.0.0 · Source

impl Display for ParseFloatError

1.0.0 · Source

impl Display for ParseIntError

Source

impl Display for PreInstantiationError

1.0.0 · Source

impl Display for RecvError

1.15.0 · Source

impl Display for wasmer_types::lib::std::sync::mpmc::RecvTimeoutError

Source

impl Display for Riscv32Architecture

Source

impl Display for Riscv64Architecture

Source

impl Display for SerializeError

1.0.0 · Source

impl Display for SocketAddr

1.0.0 · Source

impl Display for SocketAddrV4

1.0.0 · Source

impl Display for SocketAddrV6

Source

impl Display for SourceLoc

Source

impl Display for StoreId

1.0.0 · Source

impl Display for String

1.7.0 · Source

impl Display for StripPrefixError

Source

impl Display for StructCheckContext

1.8.0 · Source

impl Display for SystemTimeError

Source

impl Display for TableType

Source

impl Display for TagType

Source

impl Display for ToCasefold

1.16.0 · Source

impl Display for ToLowercase

Source

impl Display for ToTitlecase

1.16.0 · Source

impl Display for ToUppercase

Source

impl Display for TrapCode

Source

impl Display for Triple

1.59.0 · Source

impl Display for TryFromCharError

1.66.0 · Source

impl Display for TryFromFloatSecsError

1.34.0 · Source

impl Display for TryFromIntError

Source

impl Display for TryFromIteratorError

1.35.0 · Source

impl Display for TryFromSliceError

Source

impl Display for TryGetError

1.89.0 · Source

impl Display for std::fs::TryLockError

1.0.0 · Source

impl Display for wasmer_types::lib::std::sync::mpmc::TryRecvError

1.57.0 · Source

impl Display for alloc::collections::TryReserveError

Source

impl Display for hashbrown::TryReserveError

Source

impl Display for indexmap::TryReserveError

Source

impl Display for TupleStructCheckContext

Source

impl Display for Type

Source

impl Display for UnnamedEnumVariantCheckContext

Source

impl Display for UnorderedKeyError

Source

impl Display for UserAbort

1.0.0 · Source

impl Display for core::str::error::Utf8Error

Source

impl Display for simdutf8::basic::Utf8Error

Source

impl Display for simdutf8::compat::Utf8Error

1.0.0 · Source

impl Display for VarError

Source

impl Display for Vendor

Source

impl Display for WasmError

Source

impl Display for WouldBlock

1.56.0 · Source

impl Display for WriterPanicked

Source

impl Display for X86_32Architecture

1.0.0 · Source

impl Display for bool

1.0.0 · Source

impl Display for char

Source

impl Display for char_be

Source

impl Display for char_le

Source

impl Display for char_ube

Source

impl Display for char_ule

1.0.0 · Source

impl Display for f16

1.0.0 · Source

impl Display for f32

1.0.0 · Source

impl Display for f64

Source

impl Display for f32_be

Source

impl Display for f32_le

Source

impl Display for f32_ube

Source

impl Display for f32_ule

Source

impl Display for f64_be

Source

impl Display for f64_le

Source

impl Display for f64_ube

Source

impl Display for f64_ule

1.0.0 · Source

impl Display for i8

1.0.0 · Source

impl Display for i16

1.0.0 · Source

impl Display for i32

1.0.0 · Source

impl Display for i64

Source

impl Display for i16_be

Source

impl Display for i16_le

Source

impl Display for i16_ube

Source

impl Display for i16_ule

Source

impl Display for i32_be

Source

impl Display for i32_le

Source

impl Display for i32_ube

Source

impl Display for i32_ule

Source

impl Display for i64_be

Source

impl Display for i64_le

Source

impl Display for i64_ube

Source

impl Display for i64_ule

1.0.0 · Source

impl Display for i128

Source

impl Display for i128_be

Source

impl Display for i128_le

Source

impl Display for i128_ube

Source

impl Display for i128_ule

1.0.0 · Source

impl Display for isize

1.0.0 · Source

impl Display for str

1.0.0 · Source

impl Display for u8

1.0.0 · Source

impl Display for u16

1.0.0 · Source

impl Display for u32

1.0.0 · Source

impl Display for u64

Source

impl Display for u16_be

Source

impl Display for u16_le

Source

impl Display for u16_ube

Source

impl Display for u16_ule

Source

impl Display for u32_be

Source

impl Display for u32_le

Source

impl Display for u32_ube

Source

impl Display for u32_ule

Source

impl Display for u64_be

Source

impl Display for u64_le

Source

impl Display for u64_ube

Source

impl Display for u64_ule

1.0.0 · Source

impl Display for u128

Source

impl Display for u128_be

Source

impl Display for u128_le

Source

impl Display for u128_ube

Source

impl Display for u128_ule

1.0.0 · Source

impl Display for usize

Source

impl<'a, I> Display for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Display,

1.60.0 · Source

impl<'a> Display for EscapeAscii<'a>

1.34.0 · Source

impl<'a> Display for core::str::iter::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Display for core::str::iter::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Display for core::str::iter::EscapeUnicode<'a>

1.0.0 · Source

impl<B> Display for Cow<'_, B>
where B: Display + ToOwned + ?Sized, <B as ToOwned>::Owned: Display,

Source

impl<E> Display for Report<E>
where E: Error,

1.93.0 · Source

impl<F> Display for FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,

Source

impl<I, F> Display for FormatWith<'_, I, F>
where I: Iterator, F: FnMut(<I as Iterator>::Item, &mut dyn FnMut(&dyn Display) -> Result<(), Error>) -> Result<(), Error>,

Source

impl<I> Display for ExactlyOneError<I>
where I: Iterator,

Source

impl<Item> Display for AllEqualValueError<Item>

Source

impl<K, V, S, A> Display for OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<L, R> Display for Either<L, R>
where L: Display, R: Display,

1.33.0 · Source

impl<Ptr> Display for Pin<Ptr>
where Ptr: Display,

1.0.0 · Source

impl<T, A> Display for Arc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Box<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Rc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueArc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueRc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, F> Display for ArchivedRc<T, F>

1.0.0 · Source

impl<T> Display for &T
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for &mut T
where T: Display + ?Sized,

Source

impl<T> Display for ArchivedBox<T>

Source

impl<T> Display for EnumSet<T>
where T: EnumSetType + Display,

Source

impl<T> Display for InvalidEnumDiscriminantError<T>
where T: Display,

Source

impl<T> Display for wasmer_types::lib::std::sync::nonpoison::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for wasmer_types::lib::std::sync::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for wasmer_types::lib::std::sync::nonpoison::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for wasmer_types::lib::std::sync::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for wasmer_types::lib::std::sync::nonpoison::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for wasmer_types::lib::std::sync::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for MixedEnumSet<T>

Source

impl<T> Display for MixedValue<T>
where T: EnumSetType + Display,

Source

impl<T> Display for wasmer_types::lib::std::sync::nonpoison::MutexGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for wasmer_types::lib::std::sync::MutexGuard<'_, T>
where T: Display + ?Sized,

1.28.0 · Source

impl<T> Display for NonZero<T>

1.0.0 · Source

impl<T> Display for PoisonError<T>

Source

impl<T> Display for wasmer_types::lib::std::sync::oneshot::RecvTimeoutError<T>

Source

impl<T> Display for ReentrantLockGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for Ref<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for RefMut<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for wasmer_types::lib::std::sync::nonpoison::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for wasmer_types::lib::std::sync::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for wasmer_types::lib::std::sync::nonpoison::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for wasmer_types::lib::std::sync::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.74.0 · Source

impl<T> Display for Saturating<T>
where T: Display,

1.0.0 · Source

impl<T> Display for SendError<T>

Source

impl<T> Display for SendTimeoutError<T>

Source

impl<T> Display for ThinBox<T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for wasmer_types::lib::std::sync::TryLockError<T>

Source

impl<T> Display for wasmer_types::lib::std::sync::oneshot::TryRecvError<T>

1.0.0 · Source

impl<T> Display for TrySendError<T>

1.10.0 · Source

impl<T> Display for Wrapping<T>
where T: Display,

1.0.0 · Source

impl<W> Display for IntoInnerError<W>

Source

impl<const MAX_SIZE: usize> Display for ObjectIdentifier<MAX_SIZE>