Hash

Trait Hash 

1.0.0 · Source
pub trait Hash {
    // Required method
    fn hash<H>(&self, state: &mut H)
       where H: Hasher;

    // Provided method
    fn hash_slice<H>(data: &[Self], state: &mut H)
       where H: Hasher,
             Self: Sized { ... }
}
Available on crate feature std only.
A hashable type.

Types implementing Hash are able to be hashed with an instance of Hasher.

Implementing Hash

You can derive Hash with #[derive(Hash)] if all fields implement Hash. The resulting hash will be the combination of the values from calling hash on each field.

#[derive(Hash)]
struct Rustacean {
    name: String,
    country: String,
}

If you need more control over how a value is hashed, you can of course implement the Hash trait yourself:

use std::hash::{Hash, Hasher};

struct Person {
    id: u32,
    name: String,
    phone: u64,
}

impl Hash for Person {
    fn hash<H: Hasher>(&self, state: &mut H) {
        self.id.hash(state);
        self.phone.hash(state);
    }
}

Hash and Eq

When implementing both Hash and Eq, it is important that the following property holds:

k1 == k2 -> hash(k1) == hash(k2)

In other words, if two keys are equal, their hashes must also be equal. HashMap and HashSet both rely on this behavior.

Thankfully, you won’t need to worry about upholding this property when deriving both Eq and Hash with #[derive(PartialEq, Eq, Hash)].

Violating this property is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Prefix collisions

Implementations of hash should ensure that the data they pass to the Hasher are prefix-free. That is, values which are not equal should cause two different sequences of values to be written, and neither of the two sequences should be a prefix of the other.

For example, the standard implementation of Hash for &str passes an extra 0xFF byte to the Hasher so that the values ("ab", "c") and ("a", "bc") hash differently.

Portability

Due to differences in endianness and type sizes, data fed by Hash to a Hasher should not be considered portable across platforms. Additionally the data passed by most standard library types should not be considered stable between compiler versions.

This means tests shouldn’t probe hard-coded hash values or data fed to a Hasher and instead should check consistency with Eq.

Serialization formats intended to be portable between platforms or compiler versions should either avoid encoding hashes or only rely on Hash and Hasher implementations that provide additional guarantees.

Required Methods

1.0.0 · Source

fn hash<H>(&self, state: &mut H)
where H: Hasher,

Feeds this value into the given Hasher.

Examples
use std::hash::{DefaultHasher, Hash, Hasher};

let mut hasher = DefaultHasher::new();
7920.hash(&mut hasher);
println!("Hash is {:x}!", hasher.finish());

Provided Methods

1.3.0 · Source

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher.

This method is meant as a convenience, but its implementation is also explicitly left unspecified. It isn’t guaranteed to be equivalent to repeated calls of hash and implementations of Hash should keep that in mind and call hash themselves if the slice isn’t treated as a whole unit in the PartialEq implementation.

For example, a VecDeque implementation might naïvely call as_slices and then hash_slice on each slice, but this is wrong since the two slices can change with a call to make_contiguous without affecting the PartialEq result. Since these slices aren’t treated as singular units, and instead part of a larger deque, this method cannot be used.

Examples
use std::hash::{DefaultHasher, Hash, Hasher};

let mut hasher = DefaultHasher::new();
let numbers = [6, 28, 496, 8128];
Hash::hash_slice(&numbers, &mut hasher);
println!("Hash is {:x}!", hasher.finish());

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.29.0 · Source

impl Hash for !

1.0.0 · Source

impl Hash for ()

Source

impl Hash for ATerm

Source

impl Hash for Aarch64Architecture

Source

impl Hash for Alignment

Source

impl Hash for Architecture

Source

impl Hash for ArchivedCString

Source

impl Hash for ArchivedDuration

Source

impl Hash for ArchivedIpAddr

Source

impl Hash for ArchivedIpv4Addr

Source

impl Hash for ArchivedIpv6Addr

Source

impl Hash for ArchivedOptionNonZeroI8

Source

impl Hash for ArchivedOptionNonZeroI16

Source

impl Hash for ArchivedOptionNonZeroI32

Source

impl Hash for ArchivedOptionNonZeroI64

Source

impl Hash for ArchivedOptionNonZeroI128

Source

impl Hash for ArchivedOptionNonZeroU8

Source

impl Hash for ArchivedOptionNonZeroU16

Source

impl Hash for ArchivedOptionNonZeroU32

Source

impl Hash for ArchivedOptionNonZeroU64

Source

impl Hash for ArchivedOptionNonZeroU128

Source

impl Hash for ArchivedRangeFull

Source

impl Hash for ArchivedSocketAddr

Source

impl Hash for ArchivedSocketAddrV4

Source

impl Hash for ArchivedSocketAddrV6

Source

impl Hash for ArchivedString

Source

impl Hash for ArmArchitecture

Source

impl Hash for AsciiChar

Source

impl Hash for AtomicsError

Source

impl Hash for B0

Source

impl Hash for B1

Source

impl Hash for BinaryFormat

Source

impl Hash for ByteStr

Source

impl Hash for ByteString

Source

impl Hash for bytes::bytes::Bytes

Source

impl Hash for wasmer_types::Bytes

Source

impl Hash for BytesMut

Source

impl Hash for CDataModel

1.64.0 · Source

impl Hash for CStr

1.64.0 · Source

impl Hash for CString

Source

impl Hash for CallingConvention

Source

impl Hash for CharCase

Source

impl Hash for CleverArchitecture

Source

impl Hash for CpuFeature

Source

impl Hash for CustomSectionIndex

Source

impl Hash for CustomVendor

Source

impl Hash for DataIndex

Source

impl Hash for DefaultToHost

Source

impl Hash for DefaultToUnknown

Source

impl Hash for DeploymentTarget

1.3.0 · Source

impl Hash for Duration

Source

impl Hash for ElemIndex

Source

impl Hash for Endianness

Source

impl Hash for Environment

Source

impl Hash for Equal

1.0.0 · Source

impl Hash for Error

1.0.0 · Source

impl Hash for ErrorKind

Source

impl Hash for ExportIndex

Source

impl Hash for ExternType

Source

impl Hash for Failure

Source

impl Hash for Features

Source

impl Hash for FieldId

1.1.0 · Source

impl Hash for FileType

Source

impl Hash for FunctionIndex

Source

impl Hash for FunctionType

Source

impl Hash for GlobalIndex

Source

impl Hash for GlobalType

Source

impl Hash for Greater

Source

impl Hash for ImportIndex

Source

impl Hash for ImportKey

1.44.0 · Source

impl Hash for Infallible

Source

impl Hash for InitExpr

Source

impl Hash for InitExprOp

1.8.0 · Source

impl Hash for Instant

1.55.0 · Source

impl Hash for IntErrorKind

1.7.0 · Source

impl Hash for IpAddr

1.0.0 · Source

impl Hash for Ipv4Addr

1.0.0 · Source

impl Hash for Ipv6Addr

Source

impl Hash for Ipv6MulticastScope

1.28.0 · Source

impl Hash for Layout

Source

impl Hash for Less

Source

impl Hash for LibCall

Source

impl Hash for LocalFunctionIndex

Source

impl Hash for LocalGlobalIndex

Source

impl Hash for LocalMemoryIndex

Source

impl Hash for LocalTableIndex

Source

impl Hash for LocalTagIndex

Source

impl Hash for Locality

1.10.0 · Source

impl Hash for Location<'_>

Source

impl Hash for MemoryError

Source

impl Hash for MemoryIndex

Source

impl Hash for MemoryStyle

Source

impl Hash for MemoryType

Source

impl Hash for Mips32Architecture

Source

impl Hash for Mips64Architecture

Source

impl Hash for ModuleHash

Source

impl Hash for Mutability

Source

impl Hash for NonZeroI16_be

Source

impl Hash for NonZeroI16_le

Source

impl Hash for NonZeroI16_ube

Source

impl Hash for NonZeroI16_ule

Source

impl Hash for NonZeroI32_be

Source

impl Hash for NonZeroI32_le

Source

impl Hash for NonZeroI32_ube

Source

impl Hash for NonZeroI32_ule

Source

impl Hash for NonZeroI64_be

Source

impl Hash for NonZeroI64_le

Source

impl Hash for NonZeroI64_ube

Source

impl Hash for NonZeroI64_ule

Source

impl Hash for NonZeroI128_be

Source

impl Hash for NonZeroI128_le

Source

impl Hash for NonZeroI128_ube

Source

impl Hash for NonZeroI128_ule

Source

impl Hash for NonZeroU16_be

Source

impl Hash for NonZeroU16_le

Source

impl Hash for NonZeroU16_ube

Source

impl Hash for NonZeroU16_ule

Source

impl Hash for NonZeroU32_be

Source

impl Hash for NonZeroU32_le

Source

impl Hash for NonZeroU32_ube

Source

impl Hash for NonZeroU32_ule

Source

impl Hash for NonZeroU64_be

Source

impl Hash for NonZeroU64_le

Source

impl Hash for NonZeroU64_ube

Source

impl Hash for NonZeroU64_ule

Source

impl Hash for NonZeroU128_be

Source

impl Hash for NonZeroU128_le

Source

impl Hash for NonZeroU128_ube

Source

impl Hash for NonZeroU128_ule

Source

impl Hash for ObjectIdentifierRef

Source

impl Hash for OperatingSystem

1.0.0 · Source

impl Hash for wasmer_types::lib::std::cmp::Ordering

1.0.0 · Source

impl Hash for wasmer_types::lib::std::sync::atomic::Ordering

1.0.0 · Source

impl Hash for OsStr

1.0.0 · Source

impl Hash for OsString

Source

impl Hash for Pages

Source

impl Hash for Panic

1.0.0 · Source

impl Hash for Path

1.0.0 · Source

impl Hash for PathBuf

1.33.0 · Source

impl Hash for PhantomPinned

Source

impl Hash for PointerWidth

1.0.0 · Source

impl Hash for PrefixComponent<'_>

1.0.0 · Source

impl Hash for RangeFull

Source

impl Hash for Riscv32Architecture

Source

impl Hash for Riscv64Architecture

Source

impl Hash for SignatureHash

Source

impl Hash for SignatureIndex

Source

impl Hash for Size

1.0.0 · Source

impl Hash for SocketAddr

1.0.0 · Source

impl Hash for SocketAddrV4

1.0.0 · Source

impl Hash for SocketAddrV6

Source

impl Hash for StoreId

1.0.0 · Source

impl Hash for String

1.8.0 · Source

impl Hash for SystemTime

Source

impl Hash for TableIndex

Source

impl Hash for TableInitializer

Source

impl Hash for TableStyle

Source

impl Hash for TableType

Source

impl Hash for Tag

Source

impl Hash for TagIndex

Source

impl Hash for TagKind

Source

impl Hash for TagType

Source

impl Hash for Target

1.19.0 · Source

impl Hash for ThreadId

Source

impl Hash for TrapCode

Source

impl Hash for Triple

Source

impl Hash for Type

1.0.0 · Source

impl Hash for TypeId

Source

impl Hash for UCred

Source

impl Hash for UTerm

Source

impl Hash for UserCompilerOptimizations

Source

impl Hash for V128

Source

impl Hash for Vendor

Source

impl Hash for X86_32Architecture

Source

impl Hash for Z0

1.0.0 · Source

impl Hash for bool

1.0.0 · Source

impl Hash for char

Source

impl Hash for char_be

Source

impl Hash for char_le

Source

impl Hash for char_ube

Source

impl Hash for char_ule

1.0.0 · Source

impl Hash for i8

1.0.0 · Source

impl Hash for i16

1.0.0 · Source

impl Hash for i32

1.0.0 · Source

impl Hash for i64

Source

impl Hash for i16_be

Source

impl Hash for i16_le

Source

impl Hash for i16_ube

Source

impl Hash for i16_ule

Source

impl Hash for i32_be

Source

impl Hash for i32_le

Source

impl Hash for i32_ube

Source

impl Hash for i32_ule

Source

impl Hash for i64_be

Source

impl Hash for i64_le

Source

impl Hash for i64_ube

Source

impl Hash for i64_ule

1.0.0 · Source

impl Hash for i128

Source

impl Hash for i128_be

Source

impl Hash for i128_le

Source

impl Hash for i128_ube

Source

impl Hash for i128_ule

1.0.0 · Source

impl Hash for isize

1.0.0 · Source

impl Hash for str

1.0.0 · Source

impl Hash for u8

1.0.0 · Source

impl Hash for u16

1.0.0 · Source

impl Hash for u32

1.0.0 · Source

impl Hash for u64

Source

impl Hash for u16_be

Source

impl Hash for u16_le

Source

impl Hash for u16_ube

Source

impl Hash for u16_ule

Source

impl Hash for u32_be

Source

impl Hash for u32_le

Source

impl Hash for u32_ube

Source

impl Hash for u32_ule

Source

impl Hash for u64_be

Source

impl Hash for u64_le

Source

impl Hash for u64_ube

Source

impl Hash for u64_ule

1.0.0 · Source

impl Hash for u128

Source

impl Hash for u128_be

Source

impl Hash for u128_le

Source

impl Hash for u128_ube

Source

impl Hash for u128_ule

1.0.0 · Source

impl Hash for usize

1.0.0 · Source

impl<'a> Hash for Component<'a>

Source

impl<'a> Hash for PhantomContravariantLifetime<'a>

Source

impl<'a> Hash for PhantomCovariantLifetime<'a>

Source

impl<'a> Hash for PhantomInvariantLifetime<'a>

1.0.0 · Source

impl<'a> Hash for Prefix<'a>

Source

impl<A, B> Hash for EitherOrBoth<A, B>
where A: Hash, B: Hash,

1.55.0 · Source

impl<B, C> Hash for ControlFlow<B, C>
where B: Hash, C: Hash,

1.0.0 · Source

impl<B> Hash for Cow<'_, B>
where B: Hash + ToOwned + ?Sized,

Source

impl<Dyn> Hash for wasmer_types::lib::std::ptr::DynMetadata<Dyn>
where Dyn: ?Sized,

Source

impl<Dyn> Hash for ptr_meta::DynMetadata<Dyn>
where Dyn: ?Sized,

1.4.0 · Source

impl<F> Hash for F
where F: FnPtr,

1.0.0 · Source

impl<Idx> Hash for wasmer_types::lib::std::ops::Range<Idx>
where Idx: Hash,

1.96.0 · Source

impl<Idx> Hash for core::range::Range<Idx>
where Idx: Hash,

1.0.0 · Source

impl<Idx> Hash for wasmer_types::lib::std::ops::RangeFrom<Idx>
where Idx: Hash,

1.96.0 · Source

impl<Idx> Hash for core::range::RangeFrom<Idx>
where Idx: Hash,

1.26.0 · Source

impl<Idx> Hash for wasmer_types::lib::std::ops::RangeInclusive<Idx>
where Idx: Hash,

1.95.0 · Source

impl<Idx> Hash for core::range::RangeInclusive<Idx>
where Idx: Hash,

1.0.0 · Source

impl<Idx> Hash for RangeTo<Idx>
where Idx: Hash,

1.26.0 · Source

impl<Idx> Hash for wasmer_types::lib::std::ops::RangeToInclusive<Idx>
where Idx: Hash,

1.96.0 · Source

impl<Idx> Hash for core::range::RangeToInclusive<Idx>
where Idx: Hash,

1.0.0 · Source

impl<K, V, A> Hash for BTreeMap<K, V, A>
where K: Hash, V: Hash, A: Allocator + Clone,

Source

impl<K, V, const E: usize> Hash for ArchivedBTreeMap<K, V, E>
where K: Hash, V: Hash,

Source

impl<K, V: Hash> Hash for PrimaryMap<K, V>
where K: EntityRef + Hash,

Source

impl<K, V> Hash for Entry<K, V>
where K: Hash, V: Hash,

Source

impl<K, V> Hash for indexmap::map::slice::Slice<K, V>
where K: Hash, V: Hash,

Source

impl<L, R> Hash for Either<L, R>
where L: Hash, R: Hash,

1.41.0 · Source

impl<Ptr> Hash for Pin<Ptr>
where Ptr: Deref, <Ptr as Deref>::Target: Hash,

Source

impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> Hash for ArchivedTuple13<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12>
where T0: Hash, T1: Hash, T2: Hash, T3: Hash, T4: Hash, T5: Hash, T6: Hash, T7: Hash, T8: Hash, T9: Hash, T10: Hash, T11: Hash, T12: Hash,

Source

impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Hash for ArchivedTuple12<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11>
where T0: Hash, T1: Hash, T2: Hash, T3: Hash, T4: Hash, T5: Hash, T6: Hash, T7: Hash, T8: Hash, T9: Hash, T10: Hash, T11: Hash,

Source

impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Hash for ArchivedTuple11<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10>
where T0: Hash, T1: Hash, T2: Hash, T3: Hash, T4: Hash, T5: Hash, T6: Hash, T7: Hash, T8: Hash, T9: Hash, T10: Hash,

Source

impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Hash for ArchivedTuple10<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9>
where T0: Hash, T1: Hash, T2: Hash, T3: Hash, T4: Hash, T5: Hash, T6: Hash, T7: Hash, T8: Hash, T9: Hash,

Source

impl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Hash for ArchivedTuple9<T0, T1, T2, T3, T4, T5, T6, T7, T8>
where T0: Hash, T1: Hash, T2: Hash, T3: Hash, T4: Hash, T5: Hash, T6: Hash, T7: Hash, T8: Hash,

Source

impl<T0, T1, T2, T3, T4, T5, T6, T7> Hash for ArchivedTuple8<T0, T1, T2, T3, T4, T5, T6, T7>
where T0: Hash, T1: Hash, T2: Hash, T3: Hash, T4: Hash, T5: Hash, T6: Hash, T7: Hash,

Source

impl<T0, T1, T2, T3, T4, T5, T6> Hash for ArchivedTuple7<T0, T1, T2, T3, T4, T5, T6>
where T0: Hash, T1: Hash, T2: Hash, T3: Hash, T4: Hash, T5: Hash, T6: Hash,

Source

impl<T0, T1, T2, T3, T4, T5> Hash for ArchivedTuple6<T0, T1, T2, T3, T4, T5>
where T0: Hash, T1: Hash, T2: Hash, T3: Hash, T4: Hash, T5: Hash,

Source

impl<T0, T1, T2, T3, T4> Hash for ArchivedTuple5<T0, T1, T2, T3, T4>
where T0: Hash, T1: Hash, T2: Hash, T3: Hash, T4: Hash,

Source

impl<T0, T1, T2, T3> Hash for ArchivedTuple4<T0, T1, T2, T3>
where T0: Hash, T1: Hash, T2: Hash, T3: Hash,

Source

impl<T0, T1, T2> Hash for ArchivedTuple3<T0, T1, T2>
where T0: Hash, T1: Hash, T2: Hash,

Source

impl<T0, T1> Hash for ArchivedTuple2<T0, T1>
where T0: Hash, T1: Hash,

Source

impl<T0> Hash for ArchivedTuple1<T0>
where T0: Hash,

1.0.0 · Source

impl<T, A> Hash for Arc<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for BTreeSet<T, A>
where T: Hash, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> Hash for Box<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for LinkedList<T, A>
where T: Hash, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Rc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for UniqueArc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for UniqueRc<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Vec<T, A>
where T: Hash, A: Allocator,

The hash of a vector is the same as that of the corresponding slice, as required by the core::borrow::Borrow implementation.

use std::hash::BuildHasher;

let b = std::hash::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));
1.0.0 · Source

impl<T, A> Hash for VecDeque<T, A>
where T: Hash, A: Allocator,

Source

impl<T, E> Hash for ArchivedResult<T, E>
where T: Hash, E: Hash,

1.0.0 · Source

impl<T, E> Hash for Result<T, E>
where T: Hash, E: Hash,

Source

impl<T, F> Hash for ArchivedRc<T, F>
where T: ArchivePointee + Hash + ?Sized,

Source

impl<T, U> Hash for Array<T, U>
where T: Hash, U: ArraySize,

Source

impl<T, const N: usize> Hash for Simd<T, N>
where T: SimdElement + Hash,

1.0.0 · Source

impl<T, const N: usize> Hash for [T; N]
where T: Hash,

The hash of an array is the same as that of the corresponding slice, as required by the Borrow implementation.

use std::hash::BuildHasher;

let b = std::hash::RandomState::new();
let a: [u8; 3] = [0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(a), b.hash_one(s));
Source

impl<T, const VARIANT: u32, const FIELD: u32> Hash for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,

Source

impl<T: Hash + ReservedValue> Hash for PackedOption<T>

Source

impl<T: Hash> Hash for ExportType<T>

Source

impl<T: Hash> Hash for ImportType<T>

1.0.0 · Source

impl<T> Hash for &T
where T: Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for &mut T
where T: Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for (T₁, T₂, …, Tₙ)
where T: Hash,

This trait is implemented for tuples up to twelve items long.

1.0.0 · Source

impl<T> Hash for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for *mut T
where T: ?Sized,

Source

impl<T> Hash for ArchivedBound<T>
where T: Hash,

Source

impl<T> Hash for ArchivedBox<T>
where T: ArchivePointee + Hash + ?Sized,

Source

impl<T> Hash for ArchivedOption<T>
where T: Hash,

Source

impl<T> Hash for ArchivedOptionBox<T>
where T: ArchivePointee + Hash + ?Sized,

Source

impl<T> Hash for ArchivedRange<T>
where T: Hash,

Source

impl<T> Hash for ArchivedRangeFrom<T>
where T: Hash,

Source

impl<T> Hash for ArchivedRangeInclusive<T>
where T: Hash,

Source

impl<T> Hash for ArchivedRangeTo<T>
where T: Hash,

Source

impl<T> Hash for ArchivedRangeToInclusive<T>
where T: Hash,

Source

impl<T> Hash for ArchivedVec<T>
where T: Hash,

1.17.0 · Source

impl<T> Hash for Bound<T>
where T: Hash,

1.21.0 · Source

impl<T> Hash for Discriminant<T>

Source

impl<T> Hash for EnumSet<T>
where T: EnumSetType,

1.20.0 · Source

impl<T> Hash for ManuallyDrop<T>
where T: Hash + ?Sized,

Source

impl<T> Hash for MixedEnumSet<T>

Source

impl<T> Hash for MixedValue<T>
where T: Hash + EnumSetType,

1.25.0 · Source

impl<T> Hash for NonNull<T>
where T: ?Sized,

1.28.0 · Source

impl<T> Hash for NonZero<T>

1.0.0 · Source

impl<T> Hash for Option<T>
where T: Hash,

Source

impl<T> Hash for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomCovariant<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for PhantomData<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomInvariant<T>
where T: ?Sized,

1.36.0 · Source

impl<T> Hash for Poll<T>
where T: Hash,

1.19.0 · Source

impl<T> Hash for Reverse<T>
where T: Hash,

1.74.0 · Source

impl<T> Hash for Saturating<T>
where T: Hash,

Source

impl<T> Hash for indexmap::set::slice::Slice<T>
where T: Hash,

Source

impl<T> Hash for SyncView<T>
where T: Sync + Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for Wrapping<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for [T]
where T: Hash,

Source

impl<U, B> Hash for UInt<U, B>
where U: Hash, B: Hash,

Source

impl<U> Hash for NInt<U>
where U: Hash + Unsigned + NonZero,

Source

impl<U> Hash for PInt<U>
where U: Hash + Unsigned + NonZero,

Source

impl<V, A> Hash for TArr<V, A>
where V: Hash, A: Hash,

Source

impl<Y, R> Hash for CoroutineState<Y, R>
where Y: Hash, R: Hash,

Source

impl<const MAX_SIZE: usize> Hash for ObjectIdentifier<MAX_SIZE>

Source

impl<const SIZE: usize> Hash for Buffer<SIZE>