pub trait IntoIterator {
type Item;
type IntoIter: Iterator<Item = Self::Item>;
// Required method
fn into_iter(self) -> Self::IntoIter;
}Expand description
Conversion into an Iterator.
By implementing IntoIterator for a type, you define how it will be
converted to an iterator. This is common for types which describe a
collection of some kind.
One benefit of implementing IntoIterator is that your type will work
with Rust’s for loop syntax.
See also: FromIterator.
Examples
Basic usage:
let v = [1, 2, 3];
let mut iter = v.into_iter();
assert_eq!(Some(1), iter.next());
assert_eq!(Some(2), iter.next());
assert_eq!(Some(3), iter.next());
assert_eq!(None, iter.next());Implementing IntoIterator for your type:
// A sample collection, that's just a wrapper over Vec<T>
#[derive(Debug)]
struct MyCollection(Vec<i32>);
// Let's give it some methods so we can create one and add things
// to it.
impl MyCollection {
fn new() -> MyCollection {
MyCollection(Vec::new())
}
fn add(&mut self, elem: i32) {
self.0.push(elem);
}
}
// and we'll implement IntoIterator
impl IntoIterator for MyCollection {
type Item = i32;
type IntoIter = std::vec::IntoIter<Self::Item>;
fn into_iter(self) -> Self::IntoIter {
self.0.into_iter()
}
}
// Now we can make a new collection...
let mut c = MyCollection::new();
// ... add some stuff to it ...
c.add(0);
c.add(1);
c.add(2);
// ... and then turn it into an Iterator:
for (i, n) in c.into_iter().enumerate() {
assert_eq!(i as i32, n);
}It is common to use IntoIterator as a trait bound. This allows
the input collection type to change, so long as it is still an
iterator. Additional bounds can be specified by restricting on
Item:
fn collect_as_strings<T>(collection: T) -> Vec<String>
where
T: IntoIterator,
T::Item: std::fmt::Debug,
{
collection
.into_iter()
.map(|item| format!("{item:?}"))
.collect()
}Required Associated Types
Required Methods
1.0.0 · Sourcefn into_iter(self) -> Self::IntoIter
fn into_iter(self) -> Self::IntoIter
Creates an iterator from a value.
See the module-level documentation for more.
Examples
let v = [1, 2, 3];
let mut iter = v.into_iter();
assert_eq!(Some(1), iter.next());
assert_eq!(Some(2), iter.next());
assert_eq!(Some(3), iter.next());
assert_eq!(None, iter.next());Implementors
1.10.0 · Sourceimpl<'a> IntoIterator for &'a UnixListener
impl<'a> IntoIterator for &'a UnixListener
1.6.0 · Sourceimpl<'a> IntoIterator for &'a Path
impl<'a> IntoIterator for &'a Path
1.6.0 · Sourceimpl<'a> IntoIterator for &'a PathBuf
impl<'a> IntoIterator for &'a PathBuf
impl<'a> IntoIterator for Imports<'a>
impl<'a> IntoIterator for Imports<'a>
impl<'a> IntoIterator for LinkingSectionReader<'a>
impl<'a> IntoIterator for LinkingSectionReader<'a>
impl<'a> IntoIterator for LocalsReader<'a>
impl<'a> IntoIterator for LocalsReader<'a>
impl<'a> IntoIterator for OperatorsReader<'a>
impl<'a> IntoIterator for OperatorsReader<'a>
impl<'a, I> IntoIterator for &'a IntoChunks<I>
impl<'a, I> IntoIterator for &'a IntoChunks<I>
impl<'a, K, I, F> IntoIterator for &'a ChunkBy<K, I, F>
impl<'a, K, I, F> IntoIterator for &'a ChunkBy<K, I, F>
Sourceimpl<'a, K, V> IntoIterator for &'a BoxedSlice<K, V>where
K: EntityRef,
impl<'a, K, V> IntoIterator for &'a BoxedSlice<K, V>where
K: EntityRef,
Sourceimpl<'a, K, V> IntoIterator for &'a PrimaryMap<K, V>where
K: EntityRef,
impl<'a, K, V> IntoIterator for &'a PrimaryMap<K, V>where
K: EntityRef,
impl<'a, K, V> IntoIterator for &'a IndexMap<K, V>
impl<'a, K, V> IntoIterator for &'a IndexMap<K, V>
impl<'a, K, V> IntoIterator for &'a Map<K, V>
impl<'a, K, V> IntoIterator for &'a Map<K, V>
impl<'a, K, V> IntoIterator for &'a Slice<K, V>
impl<'a, K, V> IntoIterator for &'a Slice<K, V>
Sourceimpl<'a, K, V> IntoIterator for &'a mut BoxedSlice<K, V>where
K: EntityRef,
impl<'a, K, V> IntoIterator for &'a mut BoxedSlice<K, V>where
K: EntityRef,
Sourceimpl<'a, K, V> IntoIterator for &'a mut PrimaryMap<K, V>where
K: EntityRef,
impl<'a, K, V> IntoIterator for &'a mut PrimaryMap<K, V>where
K: EntityRef,
impl<'a, K, V> IntoIterator for &'a mut IndexMap<K, V>
impl<'a, K, V> IntoIterator for &'a mut IndexMap<K, V>
impl<'a, K, V> IntoIterator for &'a mut Map<K, V>where
K: 'a,
V: 'a,
impl<'a, K, V> IntoIterator for &'a mut Map<K, V>where
K: 'a,
V: 'a,
impl<'a, K, V> IntoIterator for &'a mut Slice<K, V>
impl<'a, K, V> IntoIterator for &'a mut Slice<K, V>
1.0.0 · Sourceimpl<'a, K, V, A> IntoIterator for &'a BTreeMap<K, V, A>
impl<'a, K, V, A> IntoIterator for &'a BTreeMap<K, V, A>
1.0.0 · Sourceimpl<'a, K, V, A> IntoIterator for &'a mut BTreeMap<K, V, A>
impl<'a, K, V, A> IntoIterator for &'a mut BTreeMap<K, V, A>
1.0.0 · Sourceimpl<'a, K, V, S> IntoIterator for &'a std::collections::hash::map::HashMap<K, V, S>
impl<'a, K, V, S> IntoIterator for &'a std::collections::hash::map::HashMap<K, V, S>
impl<'a, K, V, S> IntoIterator for &'a IndexMap<K, V, S>
impl<'a, K, V, S> IntoIterator for &'a IndexMap<K, V, S>
1.0.0 · Sourceimpl<'a, K, V, S> IntoIterator for &'a mut std::collections::hash::map::HashMap<K, V, S>
impl<'a, K, V, S> IntoIterator for &'a mut std::collections::hash::map::HashMap<K, V, S>
impl<'a, K, V, S> IntoIterator for &'a mut IndexMap<K, V, S>
impl<'a, K, V, S> IntoIterator for &'a mut IndexMap<K, V, S>
impl<'a, K, V, S, A> IntoIterator for &'a HashMap<K, V, S, A>where
A: Allocator,
impl<'a, K, V, S, A> IntoIterator for &'a HashMap<K, V, S, A>where
A: Allocator,
impl<'a, K, V, S, A> IntoIterator for &'a mut HashMap<K, V, S, A>where
A: Allocator,
impl<'a, K, V, S, A> IntoIterator for &'a mut HashMap<K, V, S, A>where
A: Allocator,
1.4.0 · Sourceimpl<'a, T> IntoIterator for &'a Option<T>
impl<'a, T> IntoIterator for &'a Option<T>
1.0.0 · Sourceimpl<'a, T> IntoIterator for &'a [T]
impl<'a, T> IntoIterator for &'a [T]
Sourceimpl<'a, T> IntoIterator for &'a wasmer_types::lib::std::sync::mpmc::Receiver<T>
impl<'a, T> IntoIterator for &'a wasmer_types::lib::std::sync::mpmc::Receiver<T>
1.1.0 · Sourceimpl<'a, T> IntoIterator for &'a wasmer_types::lib::std::sync::mpsc::Receiver<T>
impl<'a, T> IntoIterator for &'a wasmer_types::lib::std::sync::mpsc::Receiver<T>
1.4.0 · Sourceimpl<'a, T> IntoIterator for &'a mut Option<T>
impl<'a, T> IntoIterator for &'a mut Option<T>
1.0.0 · Sourceimpl<'a, T> IntoIterator for &'a mut [T]
impl<'a, T> IntoIterator for &'a mut [T]
impl<'a, T> IntoIterator for &'a mut ArchivedOption<T>
impl<'a, T> IntoIterator for &'a mut ArchivedOption<T>
impl<'a, T> IntoIterator for Seal<'a, ArchivedOption<T>>
impl<'a, T> IntoIterator for Seal<'a, ArchivedOption<T>>
impl<'a, T> IntoIterator for SectionLimited<'a, T>where
T: FromReader<'a>,
impl<'a, T> IntoIterator for SectionLimited<'a, T>where
T: FromReader<'a>,
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a Vec<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a Vec<T, A>where
A: Allocator,
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a BinaryHeap<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a BinaryHeap<T, A>where
A: Allocator,
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a BTreeSet<T, A>
impl<'a, T, A> IntoIterator for &'a BTreeSet<T, A>
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a LinkedList<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a LinkedList<T, A>where
A: Allocator,
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a VecDeque<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a VecDeque<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a HashTable<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a HashTable<T, A>where
A: Allocator,
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a mut Vec<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a mut Vec<T, A>where
A: Allocator,
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a mut LinkedList<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a mut LinkedList<T, A>where
A: Allocator,
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a mut VecDeque<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a mut VecDeque<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a mut HashTable<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a mut HashTable<T, A>where
A: Allocator,
1.4.0 · Sourceimpl<'a, T, E> IntoIterator for &'a Result<T, E>
impl<'a, T, E> IntoIterator for &'a Result<T, E>
1.4.0 · Sourceimpl<'a, T, E> IntoIterator for &'a mut Result<T, E>
impl<'a, T, E> IntoIterator for &'a mut Result<T, E>
1.0.0 · Sourceimpl<'a, T, S> IntoIterator for &'a std::collections::hash::set::HashSet<T, S>
impl<'a, T, S> IntoIterator for &'a std::collections::hash::set::HashSet<T, S>
impl<'a, T, S, A> IntoIterator for &'a HashSet<T, S, A>where
A: Allocator,
impl<'a, T, S, A> IntoIterator for &'a HashSet<T, S, A>where
A: Allocator,
impl<'a, T, U> IntoIterator for &'a Array<T, U>where
U: ArraySize,
impl<'a, T, U> IntoIterator for &'a Array<T, U>where
U: ArraySize,
impl<'a, T, U> IntoIterator for &'a mut Array<T, U>where
U: ArraySize,
impl<'a, T, U> IntoIterator for &'a mut Array<T, U>where
U: ArraySize,
1.0.0 · Sourceimpl<'a, T, const N: usize> IntoIterator for &'a [T; N]
impl<'a, T, const N: usize> IntoIterator for &'a [T; N]
1.0.0 · Sourceimpl<'a, T, const N: usize> IntoIterator for &'a mut [T; N]
impl<'a, T, const N: usize> IntoIterator for &'a mut [T; N]
Sourceimpl<A> IntoIterator for Range<A>where
A: Step,
impl<A> IntoIterator for Range<A>where
A: Step,
Sourceimpl<A> IntoIterator for RangeFrom<A>where
A: Step,
impl<A> IntoIterator for RangeFrom<A>where
A: Step,
Sourceimpl<A> IntoIterator for RangeInclusive<A>where
A: Step,
impl<A> IntoIterator for RangeInclusive<A>where
A: Step,
impl<I> IntoIterator for &RcIter<I>where
I: Iterator,
Return an iterator from &RcIter<I> (by simply cloning it).
impl<I> IntoIterator for &RcIter<I>where
I: Iterator,
Return an iterator from &RcIter<I> (by simply cloning it).